@@ -33,7 +33,7 @@
 * @author     Sergio Carvalho <sergio.carvalho@portugalmail.com>  
 * @copyright  2004-2006 Sergio Carvalho
 * @license    http://www.gnu.org/copyleft/lesser.html  LGPL License 2.1
-* @version    CVS: $Id: Request.php 308701 2011-02-26 01:33:54Z sergiosgc $
+* @version    CVS: $Id$
 * @link       http://pear.php.net/package/XML_RPC2
 */
 
@@ -161,17 +161,17 @@ class XML_RPC2_Backend_Php_Request
         $methodName = $this->_methodName;
         $parameters = $this->getParameters();
 
-        $result = '<?xml version="1.0" encoding="' . $this->_encoding . '"?>';
-        $result .= '<methodCall>';
+        $result = '<?xml version="1.0" encoding="' . $this->_encoding . '"?>' . "\n";
+        $result .= "<methodCall>";
         $result .= "<methodName>${methodName}</methodName>";
-        $result .= '<params>';
+        $result .= "<params>";
         foreach($parameters as $parameter) {
-            $result .= '<param><value>';
+            $result .= "<param><value>";
             $result .= ($parameter instanceof XML_RPC2_Backend_Php_Value) ? $parameter->encode() : XML_RPC2_Backend_Php_Value::createFromNative($parameter)->encode();
-            $result .= '</value></param>';
+            $result .= "</value></param>";
         }
-        $result .= '</params>';
-        $result .= '</methodCall>';
+        $result .= "</params>";
+        $result .= "</methodCall>";
         return $result;
     }
     
